@@ -9,7 +9,7 @@ from .domain import domain
 from .email import email
 from .hashes import md5, sha1, sha224, sha256, sha512
 from .hostname import hostname
-from .i18n import es_cif, es_doi, es_nie, es_nif, fi_business_id, fi_ssn
+from .i18n import es_cif, es_doi, es_nie, es_nif, fi_business_id, fi_ssn, fr_department, fr_ssn
 from .iban import iban
 from .ip_address import ipv4, ipv6
 from .length import length
@@ -57,6 +57,8 @@ __all__ = (
     "es_nif",
     "fi_business_id",
     "fi_ssn",
+    "fr_department",
+    "fr_ssn",
     # ...
     "iban",
     # ip addresses
@@ -77,4 +79,4 @@ __all__ = (
     "validator",
 )
 
-__version__ = "0.21.2"
+__version__ = "0.23.0"
